@@ -36,13 +36,12 @@ public:
     /** \brief Constructor
     \param p Parent
     */
-    StatsPlugin(QObject *p, const QVariantList &);
+    StatsPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     /// Destructor
     ~StatsPlugin() override;
 
     void load() override;
     void unload() override;
-    bool versionCheck(const QString &version) const override;
     void guiUpdate() override;
 
 public Q_SLOTS:
